@@ -16,6 +16,7 @@ from datetime import datetime
 from typing import Any, Dict, List, Union
 
 from .literals import (
+    EncryptionStatusType,
     ErrorCauseType,
     ExportStatusType,
     LedgerStateType,
@@ -53,6 +54,7 @@ __all__ = (
     "JournalKinesisStreamDescriptionTypeDef",
     "JournalS3ExportDescriptionTypeDef",
     "KinesisConfigurationTypeDef",
+    "LedgerEncryptionDescriptionTypeDef",
     "LedgerSummaryTypeDef",
     "ListJournalKinesisStreamsForLedgerRequestRequestTypeDef",
     "ListJournalKinesisStreamsForLedgerResponseTypeDef",
@@ -106,6 +108,7 @@ _OptionalCreateLedgerRequestRequestTypeDef = TypedDict(
     {
         "Tags": Dict[str, str],
         "DeletionProtection": bool,
+        "KmsKey": str,
     },
     total=False,
 )
@@ -126,6 +129,7 @@ CreateLedgerResponseTypeDef = TypedDict(
         "CreationDateTime": datetime,
         "PermissionsMode": PermissionsModeType,
         "DeletionProtection": bool,
+        "KmsKeyArn": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -185,6 +189,7 @@ DescribeLedgerResponseTypeDef = TypedDict(
         "CreationDateTime": datetime,
         "PermissionsMode": PermissionsModeType,
         "DeletionProtection": bool,
+        "EncryptionDescription": "LedgerEncryptionDescriptionTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -352,6 +357,28 @@ class KinesisConfigurationTypeDef(
     pass
 
 
+_RequiredLedgerEncryptionDescriptionTypeDef = TypedDict(
+    "_RequiredLedgerEncryptionDescriptionTypeDef",
+    {
+        "KmsKeyArn": str,
+        "EncryptionStatus": EncryptionStatusType,
+    },
+)
+_OptionalLedgerEncryptionDescriptionTypeDef = TypedDict(
+    "_OptionalLedgerEncryptionDescriptionTypeDef",
+    {
+        "InaccessibleKmsKeyDateTime": datetime,
+    },
+    total=False,
+)
+
+
+class LedgerEncryptionDescriptionTypeDef(
+    _RequiredLedgerEncryptionDescriptionTypeDef, _OptionalLedgerEncryptionDescriptionTypeDef
+):
+    pass
+
+
 LedgerSummaryTypeDef = TypedDict(
     "LedgerSummaryTypeDef",
     {
@@ -597,6 +624,7 @@ _OptionalUpdateLedgerRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateLedgerRequestRequestTypeDef",
     {
         "DeletionProtection": bool,
+        "KmsKey": str,
     },
     total=False,
 )
@@ -616,6 +644,7 @@ UpdateLedgerResponseTypeDef = TypedDict(
         "State": LedgerStateType,
         "CreationDateTime": datetime,
         "DeletionProtection": bool,
+        "EncryptionDescription": "LedgerEncryptionDescriptionTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
